@@ -15,6 +15,9 @@ import hashlib
 import signal
 import multiprocessing
 
+# Setup default flask (werkzeug) parser
+import logging
+logger = logging.getLogger('werkzeug')
 
 
 class Popen(subprocess.Popen):
@@ -92,6 +95,44 @@ def saveSession(config, account):
       pass
     return str(e)
 
+def getCurrentSoftwareReleaseProfile(config):
+  """
+  Returns used Software Release profile as a string.
+  """
+  try:
+    software_folder = open(
+        os.path.join(config['etc_dir'], ".project")).read()
+    return realpath(
+        config, os.path.join(software_folder, config['software_profile']))
+  except:
+    return False
+
+def requestInstance(config, software_type=None):
+  """
+  Request the main instance of our environment
+  """
+  if not software_type:
+    software_type = None
+
+  slap = slapos.slap.slap()
+  profile = getCurrentSoftwareReleaseProfile(config)
+  slap.initializeConnection(config['master_url'])
+
+  param_path = os.path.join(config['etc_dir'], ".parameter.xml")
+  xml_result = readParameters(param_path)
+  partition_parameter_kw = None
+  if type(xml_result) != type('') and xml_result.has_key('instance'):
+    partition_parameter_kw = xml_result['instance']
+
+  return slap.registerOpenOrder().request(
+      profile,
+      partition_reference=getSoftwareReleaseName(config),
+      partition_parameter_kw=partition_parameter_kw,
+      software_type=software_type,
+      filter_kw=None,
+      state=None,
+      shared=False)
+
 def updateProxy(config):
   """
   Configure Slapos Node computer and partitions.
@@ -100,14 +141,7 @@ def updateProxy(config):
   if not os.path.exists(config['instance_root']):
     os.mkdir(config['instance_root'])
   slap = slapos.slap.slap()
-  #Get current software release profile
-  try:
-    software_folder = open(os.path.join(config['etc_dir'],
-                                        ".project")).read()
-    profile = realpath(config, os.path.join(software_folder,
-                                          config['software_profile']))
-  except:
-    return False
+  profile = getCurrentSoftwareReleaseProfile(config)
 
   slap.initializeConnection(config['master_url'])
   slap.registerSupply().supply(profile, computer_guid=config['computer_id'])
@@ -135,16 +169,7 @@ def updateProxy(config):
                      'reference': partition_reference,
                      'tap': {'name': partition_reference},
                      })
-  #get instance parameter
-  param_path = os.path.join(config['etc_dir'], ".parameter.xml")
-  xml_result = readParameters(param_path)
-  partition_parameter_kw = None
-  if type(xml_result) != type('') and xml_result.has_key('instance'):
-    partition_parameter_kw = xml_result['instance']
   computer.updateConfiguration(xml_marshaller.dumps(slap_config))
-  sr_request = slap.registerOpenOrder().request(profile, partition_reference=getSoftwareReleaseName(config),
-                partition_parameter_kw=partition_parameter_kw, software_type=None,
-                filter_kw=None, state=None, shared=False)
   return True
 
 def readPid(file):
@@ -170,25 +195,8 @@ def updateInstanceParameter(config, software_type=None):
     config: Slaprunner configuration.
     software_type: reconfigure Software Instance with software type.
   """
-  slap = slapos.slap.slap()
-  slap.initializeConnection(config['master_url'])
-  #Get current software release profile
-  try:
-    software_folder = open(os.path.join(config['etc_dir'],
-                                        ".project")).read()
-    profile = realpath(config, os.path.join(software_folder,
-                                          config['software_profile']))
-  except:
-    raise Exception("Software Release profile not found")
-  #get instance parameter
-  param_path = os.path.join(config['etc_dir'], ".parameter.xml")
-  xml_result = readParameters(param_path)
-  partition_parameter_kw = None
-  if type(xml_result) != type('') and xml_result.has_key('instance'):
-    partition_parameter_kw = xml_result['instance']
-  slap.registerOpenOrder().request(profile, partition_reference=getSoftwareReleaseName(config),
-          partition_parameter_kw=partition_parameter_kw, software_type=software_type,
-          filter_kw=None, state=None, shared=False)
+  if not (updateProxy(config) and requestInstance(config, software_type)):
+    return False
 
 def startProxy(config):
   """Start Slapproxy server"""
@@ -273,18 +281,18 @@ def runSoftwareWithLock(config):
     for path in os.listdir(config['software_root']):
       exist = False
       for val in data:
-	if val['md5'] == path:
-	  exist = True
+        if val['md5'] == path:
+          exist = True
       conf = os.path.join(config['etc_dir'], ".project")
       if not exist: #save this compile software folder
-	if os.path.exists(conf):
-	  data.append({"title":getProjectTitle(config), "md5":path,
-	              "path": open(os.path.join(config['etc_dir'],
-	                                        ".project"), 'r').read()})
-	  writeSoftwareData(config['etc_dir'], data)
-	else:
-	  shutil.rmtree(os.path.join(config['software_root'], path))
-	break
+        if os.path.exists(conf):
+          data.append({"title":getProjectTitle(config), "md5":path,
+                      "path": open(os.path.join(config['etc_dir'],
+                                                ".project"), 'r').read()})
+          writeSoftwareData(config['etc_dir'], data)
+        else:
+          shutil.rmtree(os.path.join(config['software_root'], path))
+        break
     return True
   return False
 
@@ -325,7 +333,7 @@ def recursifKill(pids):
       try:
         os.kill(pid, signal.SIGKILL) #kill current process
       except Exception:
-	      pass
+              pass
       recursifKill(ppids) #kill all children of this process
 
 def pidppid(pid):
@@ -344,7 +352,7 @@ def runInstanceWithLock(config):
   if not isInstanceRunning(config):
     startProxy(config)
     logfile = open(config['instance_log'], 'w')
-    if not updateProxy(config):
+    if not (updateProxy(config) and requestInstance(config)):
       return False
     svcStopAll(config) #prevent lost control of process
     slapgrid = Popen([config['slapgrid_cp'], '-vc',
@@ -401,10 +409,10 @@ def removeInstanceRoot(config):
     svcStopAll(config)
     for root, dirs, files in os.walk(config['instance_root']):
       for fname in dirs:
-	fullPath = os.path.join(root, fname)
-	if not os.access(fullPath, os.W_OK) :
-	  # Some directories may be read-only, preventing to remove files in it
-	  os.chmod(fullPath, 0744)
+        fullPath = os.path.join(root, fname)
+        if not os.access(fullPath, os.W_OK) :
+          # Some directories may be read-only, preventing to remove files in it
+          os.chmod(fullPath, 0744)
     shutil.rmtree(config['instance_root'])
 
 def getSvcStatus(config):
@@ -469,13 +477,13 @@ def getFolderContent(config, folder):
       ldir = sorted(os.listdir(realdir), key=str.lower)
     for f in ldir:
       if f.startswith('.'): #do not displays this file/folder
-	continue
+        continue
       ff=os.path.join(d,f)
       if os.path.isdir(os.path.join(realdir,f)):
-	r.append('<li class="directory collapsed"><a href="#%s" rel="%s/">%s</a></li>' % (ff, ff,f))
+        r.append('<li class="directory collapsed"><a href="#%s" rel="%s/">%s</a></li>' % (ff, ff,f))
       else:
-	e=os.path.splitext(f)[1][1:] # get .ext and remove dot
-	r.append('<li class="file ext_%s"><a href="#%s" rel="%s">%s</a></li>' % (e, ff,ff,f))
+        e=os.path.splitext(f)[1][1:] # get .ext and remove dot
+        r.append('<li class="file ext_%s"><a href="#%s" rel="%s">%s</a></li>' % (e, ff,ff,f))
     r.append('</ul>')
   except Exception,e:
     r.append('Could not load directory: %s' % str(e))
@@ -506,10 +514,10 @@ def getFolder(config, folder):
       ldir = sorted(os.listdir(realdir), key=str.lower)
     for f in ldir:
       if f.startswith('.'): #do not display this file/folder
-	continue
+        continue
       ff=os.path.join(d,f)
       if os.path.isdir(os.path.join(realdir,f)):
-	r.append('<li class="directory collapsed"><a href="#%s" rel="%s/">%s</a></li>' % (ff, ff, f))
+        r.append('<li class="directory collapsed"><a href="#%s" rel="%s/">%s</a></li>' % (ff, ff, f))
     r.append('</ul>')
   except Exception,e:
     r.append('Could not load directory: %s' % str(e))
@@ -576,10 +584,10 @@ def newSoftware(folder, config, session):
       software = "http://git.erp5.org/gitweb/slapos.git/blob_plain/HEAD:/software/lamp-template/software.cfg"
       softwareContent = ""
       try:
-	softwareContent = urllib.urlopen(software).read()
+        softwareContent = urllib.urlopen(software).read()
       except:
-	#Software.cfg and instance.cfg content will be empty
-	pass
+        #Software.cfg and instance.cfg content will be empty
+        pass
       open(os.path.join(folderPath, config['software_profile']), 'w').write(softwareContent)
       open(os.path.join(folderPath, config['instance_profile']), 'w').write("")
       open(os.path.join(basedir, ".project"), 'w').write(folder + "/")
@@ -685,15 +693,15 @@ def tail(f, lines=20):
   data = []
   while size > 0 and bytes > 0:
       if bytes - BUFSIZ > 0:
-	  # Seek back one whole BUFSIZ
-	  f.seek(block * BUFSIZ, 2)
-	  # read BUFFER
-	  data.insert(0, f.read(BUFSIZ))
+          # Seek back one whole BUFSIZ
+          f.seek(block * BUFSIZ, 2)
+          # read BUFFER
+          data.insert(0, f.read(BUFSIZ))
       else:
-	  # file too small, start from begining
-	  f.seek(0,0)
-	  # only read what was not read
-	  data.insert(0, f.read(bytes))
+          # file too small, start from begining
+          f.seek(0,0)
+          # only read what was not read
+          data.insert(0, f.read(bytes))
       linesFound = data[0].count('\n')
       size -= linesFound
       bytes -= BUFSIZ
@@ -722,10 +730,10 @@ def readFileFrom(f, lastPosition):
     else:
       margin = abs(block*BUFSIZ) - size
       if length < BUFSIZ:
-	f.seek(0,0)
+        f.seek(0,0)
       else:
-	seek = block * BUFSIZ + margin
-	f.seek(seek, 2)
+        seek = block * BUFSIZ + margin
+        f.seek(seek, 2)
       data = f.read(BUFSIZ - margin) + data
     bytes -= BUFSIZ
     block -= 1
@@ -753,27 +761,29 @@ def md5sum(file):
     while True:
       data = fh.read(8192)
       if not data:
-	break
+        break
       m.update(data)
     return m.hexdigest()
   except:
     return False
 
 def realpath(config, path, check_exist=True):
-  """Get realpath of path or return False if user is not allowed to access to
-  this file"""
+  """
+  Get realpath of path or return False if user is not allowed to access to
+  this file.
+  """
   split_path = path.split('/')
   key = split_path[0]
   allow_list = {'software_root':config['software_root'], 'instance_root':
                 config['instance_root'], 'workspace': config['workspace']}
   if allow_list.has_key(key):
     del split_path[0]
-    path = os.path.join(allow_list[key], string.join(split_path, '/'))
+    path = os.path.join(allow_list[key], *split_path)
     if check_exist:
       if os.path.exists(path):
-	return path
+        return path
       else:
-	return False
+        return False
     else:
       return path
   return False
@@ -795,7 +805,7 @@ def readParameters(path):
         for subnode in elt.childNodes:
           if subnode.nodeType != subnode.TEXT_NODE:
             sub_object[str(subnode.getAttribute('id'))] = subnode.childNodes[0].data #.decode('utf-8').decode('utf-8')
-	    object[str(elt.tagName)] = sub_object
+            object[str(elt.tagName)] = sub_object
       return object
     except Exception, e:
       return str(e)
